==> eam-wshub-proxyclient-11.5-3-sources.jar: net/datastream/schemas/mp_fields/CAPITALREQUESTCATEGORIZATIONID_Type.java <==

package net.datastream.schemas.mp_fields;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Classe Java pour CAPITALREQUESTCATEGORIZATIONID_Type complex type.
 * 
 * <p>Le fragment de schéma suivant indique le contenu attendu figurant dans cette classe.
 * 
 * <pre>
 * &lt;complexType name="CAPITALREQUESTCATEGORIZATIONID_Type">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}CAPITALREQUESTCATEGORIZATIONCODE"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}DESCRIPTION" minOccurs="0"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "CAPITALREQUESTCATEGORIZATIONID_Type", propOrder = {
    "capitalrequestcategorizationcode",
    "description"
})
public class CAPITALREQUESTCATEGORIZATIONID_Type {

    @XmlElement(name = "CAPITALREQUESTCATEGORIZATIONCODE", required = true)
    protected String capitalrequestcategorizationcode;
    @XmlElement(name = "DESCRIPTION")
    protected String description;

    /**
     * Obtient la valeur de la propriété capitalrequestcategorizationcode.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getCAPITALREQUESTCATEGORIZATIONCODE() {
        return capitalrequestcategorizationcode;
    }

    /**
     * Définit la valeur de la propriété capitalrequestcategorizationcode.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setCAPITALREQUESTCATEGORIZATIONCODE(String value) {
        this.capitalrequestcategorizationcode = value;
    }

    /**
     * Obtient la valeur de la propriété description.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getDESCRIPTION() {
        return description;
    }

    /**
     * Définit la valeur de la propriété description.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setDESCRIPTION(String value) {
        this.description = value;
    }

}

==> eam-wshub-proxyclient-12.0-sources.jar: net/datastream/schemas/mp_fields/CAPITALREQUESTCATEGORIZATIONID_Type.java <==

package net.datastream.schemas.mp_fields;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Java class for CAPITALREQUESTCATEGORIZATIONID_Type complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType name="CAPITALREQUESTCATEGORIZATIONID_Type">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}CAPITALREQUESTCATEGORIZATIONCODE"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}DESCRIPTION" minOccurs="0"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "CAPITALREQUESTCATEGORIZATIONID_Type", propOrder = {
    "capitalrequestcategorizationcode",
    "description"
})
public class CAPITALREQUESTCATEGORIZATIONID_Type {

    @XmlElement(name = "CAPITALREQUESTCATEGORIZATIONCODE", required = true)
    protected String capitalrequestcategorizationcode;
    @XmlElement(name = "DESCRIPTION")
    protected String description;

    /**
     * Gets the value of the capitalrequestcategorizationcode property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getCAPITALREQUESTCATEGORIZATIONCODE() {
        return capitalrequestcategorizationcode;
    }

    /**
     * Sets the value of the capitalrequestcategorizationcode property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setCAPITALREQUESTCATEGORIZATIONCODE(String value) {
        this.capitalrequestcategorizationcode = value;
    }

    /**
     * Gets the value of the description property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getDESCRIPTION() {
        return description;
    }

    /**
     * Sets the value of the description property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setDESCRIPTION(String value) {
        this.description = value;
    }

}
